@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: net.c 12954 2011-10-08 23:53:27Z jordan $
+ * $Id: net.c 13631 2012-12-07 01:53:31Z jordan $
  *
  * Copyright (c) Transmission authors and contributors
  *
@@ -38,82 +38,84 @@
 
 #include <event2/util.h>
 
+#include <libutp/utp.h>
+
 #include "transmission.h"
-#include "fdlimit.h" /* tr_fdSocketClose() */
+#include "fdlimit.h" /* tr_fdSocketClose () */
 #include "net.h"
-#include "peer-io.h" /* tr_peerIoAddrStr() FIXME this should be moved to net.h */
-#include "session.h" /* tr_sessionGetPublicAddress() */
-#include "tr-utp.h" /* tr_utpSendTo() */
-#include "utils.h" /* tr_time(), tr_dbg() */
+#include "peer-io.h" /* tr_peerIoAddrStr () FIXME this should be moved to net.h */
+#include "session.h" /* tr_sessionGetPublicAddress () */
+#include "tr-utp.h" /* tr_utpSendTo () */
+#include "utils.h" /* tr_time (), tr_dbg () */
 
 #ifndef IN_MULTICAST
-#define IN_MULTICAST( a ) ( ( ( a ) & 0xf0000000 ) == 0xe0000000 )
+#define IN_MULTICAST(a) (((a) & 0xf0000000) == 0xe0000000)
 #endif
 
 const tr_address tr_in6addr_any = { TR_AF_INET6, { IN6ADDR_ANY_INIT } };
 const tr_address tr_inaddr_any = { TR_AF_INET, { { { { INADDR_ANY, 0x00, 0x00, 0x00 } } } } };
 
 void
-tr_netInit( void )
+tr_netInit (void)
 {
     static int initialized = false;
 
-    if( !initialized )
+    if (!initialized)
     {
 #ifdef WIN32
         WSADATA wsaData;
-        WSAStartup( MAKEWORD( 2, 2 ), &wsaData );
+        WSAStartup (MAKEWORD (2, 2), &wsaData);
 #endif
         initialized = true;
     }
 }
 
 char *
-tr_net_strerror( char * buf, size_t buflen, int err )
+tr_net_strerror (char * buf, size_t buflen, int err)
 {
     *buf = '\0';
 #ifdef WIN32
-    FormatMessage( FORMAT_MESSAGE_FROM_SYSTEM, NULL, err, 0, buf, buflen, NULL );
+    FormatMessage (FORMAT_MESSAGE_FROM_SYSTEM, NULL, err, 0, buf, buflen, NULL);
 #else
-    tr_strlcpy( buf, tr_strerror( err ), buflen );
+    tr_strlcpy (buf, tr_strerror (err), buflen);
 #endif
     return buf;
 }
 
 const char *
-tr_address_to_string_with_buf( const tr_address * addr, char * buf, size_t buflen )
+tr_address_to_string_with_buf (const tr_address * addr, char * buf, size_t buflen)
 {
-    assert( tr_address_is_valid( addr ) );
+    assert (tr_address_is_valid (addr));
 
-    if( addr->type == TR_AF_INET )
-        return evutil_inet_ntop( AF_INET, &addr->addr, buf, buflen );
+    if (addr->type == TR_AF_INET)
+        return evutil_inet_ntop (AF_INET, &addr->addr, buf, buflen);
     else
-        return evutil_inet_ntop( AF_INET6, &addr->addr, buf, buflen );
+        return evutil_inet_ntop (AF_INET6, &addr->addr, buf, buflen);
 }
 
 /*
- * Non-threadsafe version of tr_address_to_string_with_buf()
+ * Non-threadsafe version of tr_address_to_string_with_buf ()
  * and uses a static memory area for a buffer.
  * This function is suitable to be called from libTransmission's networking code,
  * which is single-threaded.
  */
 const char *
-tr_address_to_string( const tr_address * addr )
+tr_address_to_string (const tr_address * addr)
 {
     static char buf[INET6_ADDRSTRLEN];
-    return tr_address_to_string_with_buf( addr, buf, sizeof( buf ) );
+    return tr_address_to_string_with_buf (addr, buf, sizeof (buf));
 }
 
 bool
-tr_address_from_string( tr_address * dst, const char * src )
+tr_address_from_string (tr_address * dst, const char * src)
 {
     bool ok;
 
-    if(( ok = evutil_inet_pton( AF_INET, src, &dst->addr ) == 1 ))
+    if ((ok = evutil_inet_pton (AF_INET, src, &dst->addr) == 1))
         dst->type = TR_AF_INET;
 
-    if( !ok ) /* try IPv6 */
-        if(( ok = evutil_inet_pton( AF_INET6, src, &dst->addr ) == 1 ))
+    if (!ok) /* try IPv6 */
+        if ((ok = evutil_inet_pton (AF_INET6, src, &dst->addr) == 1))
             dst->type = TR_AF_INET6;
 
     return ok;
@@ -127,15 +129,15 @@ tr_address_from_string( tr_address * dst, const char * src )
  * 0  if a == b
  */
 int
-tr_address_compare( const tr_address * a, const tr_address * b)
+tr_address_compare (const tr_address * a, const tr_address * b)
 {
-    static const int sizes[2] = { sizeof(struct in_addr), sizeof(struct in6_addr) };
+    static const int sizes[2] = { sizeof (struct in_addr), sizeof (struct in6_addr) };
 
     /* IPv6 addresses are always "greater than" IPv4 */
-    if( a->type != b->type )
+    if (a->type != b->type)
         return a->type == TR_AF_INET ? 1 : -1;
 
-    return memcmp( &a->addr, &b->addr, sizes[a->type] );
+    return memcmp (&a->addr, &b->addr, sizes[a->type]);
 }
 
 /***********************************************************************
@@ -143,21 +145,21 @@ tr_address_compare( const tr_address * a, const tr_address * b)
  **********************************************************************/
 
 int
-tr_netSetTOS( int s, int tos )
+tr_netSetTOS (int s, int tos)
 {
 #ifdef IP_TOS
-    return setsockopt( s, IPPROTO_IP, IP_TOS, (char*)&tos, sizeof( tos ) );
+    return setsockopt (s, IPPROTO_IP, IP_TOS, (char*)&tos, sizeof (tos));
 #else
     return 0;
 #endif
 }
 
 int
-tr_netSetCongestionControl( int s UNUSED, const char *algorithm UNUSED )
+tr_netSetCongestionControl (int s UNUSED, const char *algorithm UNUSED)
 {
 #ifdef TCP_CONGESTION
-    return setsockopt( s, IPPROTO_TCP, TCP_CONGESTION,
-                       algorithm, strlen(algorithm) + 1 );
+    return setsockopt (s, IPPROTO_TCP, TCP_CONGESTION,
+                       algorithm, strlen (algorithm) + 1);
 #else
     errno = ENOSYS;
     return -1;
@@ -165,11 +167,11 @@ tr_netSetCongestionControl( int s UNUSED, const char *algorithm UNUSED )
 }
 
 bool
-tr_address_from_sockaddr_storage( tr_address                     * setme_addr,
+tr_address_from_sockaddr_storage (tr_address                     * setme_addr,
                                   tr_port                        * setme_port,
-                                  const struct sockaddr_storage  * from )
+                                  const struct sockaddr_storage  * from)
 {
-    if( from->ss_family == AF_INET )
+    if (from->ss_family == AF_INET)
     {
         struct sockaddr_in * sin = (struct sockaddr_in *)from;
         setme_addr->type = TR_AF_INET;
@@ -178,7 +180,7 @@ tr_address_from_sockaddr_storage( tr_address                     * setme_addr,
         return true;
     }
 
-    if( from->ss_family == AF_INET6 )
+    if (from->ss_family == AF_INET6)
     {
         struct sockaddr_in6 *sin6 = (struct sockaddr_in6*) from;
         setme_addr->type = TR_AF_INET6;
@@ -191,40 +193,40 @@ tr_address_from_sockaddr_storage( tr_address                     * setme_addr,
 }
 
 static socklen_t
-setup_sockaddr( const tr_address        * addr,
+setup_sockaddr (const tr_address        * addr,
                 tr_port                   port,
                 struct sockaddr_storage * sockaddr)
 {
-    assert( tr_address_is_valid( addr ) );
+    assert (tr_address_is_valid (addr));
 
-    if( addr->type == TR_AF_INET )
+    if (addr->type == TR_AF_INET)
     {
         struct sockaddr_in  sock4;
-        memset( &sock4, 0, sizeof( sock4 ) );
+        memset (&sock4, 0, sizeof (sock4));
         sock4.sin_family      = AF_INET;
         sock4.sin_addr.s_addr = addr->addr.addr4.s_addr;
         sock4.sin_port        = port;
-        memcpy( sockaddr, &sock4, sizeof( sock4 ) );
-        return sizeof( struct sockaddr_in );
+        memcpy (sockaddr, &sock4, sizeof (sock4));
+        return sizeof (struct sockaddr_in);
     }
     else
     {
         struct sockaddr_in6 sock6;
-        memset( &sock6, 0, sizeof( sock6 ) );
+        memset (&sock6, 0, sizeof (sock6));
         sock6.sin6_family   = AF_INET6;
         sock6.sin6_port     = port;
         sock6.sin6_flowinfo = 0;
         sock6.sin6_addr     = addr->addr.addr6;
-        memcpy( sockaddr, &sock6, sizeof( sock6 ) );
-        return sizeof( struct sockaddr_in6 );
+        memcpy (sockaddr, &sock6, sizeof (sock6));
+        return sizeof (struct sockaddr_in6);
     }
 }
 
 int
-tr_netOpenPeerSocket( tr_session        * session,
+tr_netOpenPeerSocket (tr_session        * session,
                       const tr_address  * addr,
                       tr_port             port,
-                      bool                clientIsSeed )
+                      bool                clientIsSeed)
 {
     static const int domains[NUM_TR_AF_INET_TYPES] = { AF_INET, AF_INET6 };
     int                     s;
@@ -234,80 +236,84 @@ tr_netOpenPeerSocket( tr_session        * session,
     socklen_t               sourcelen;
     struct sockaddr_storage source_sock;
 
-    assert( tr_address_is_valid( addr ) );
+    assert (tr_address_is_valid (addr));
 
-    if( !tr_address_is_valid_for_peers( addr, port ) )
+    if (!tr_address_is_valid_for_peers (addr, port))
         return -EINVAL;
 
-    s = tr_fdSocketCreate( session, domains[addr->type], SOCK_STREAM );
-    if( s < 0 )
+    s = tr_fdSocketCreate (session, domains[addr->type], SOCK_STREAM);
+    if (s < 0)
         return -1;
 
     /* seeds don't need much of a read buffer... */
-    if( clientIsSeed ) {
+    if (clientIsSeed) {
         int n = 8192;
-        if( setsockopt( s, SOL_SOCKET, SO_RCVBUF, &n, sizeof(n) ) )
-            tr_inf( "Unable to set SO_RCVBUF on socket %d: %s", s, tr_strerror( sockerrno ) );
+        if (setsockopt (s, SOL_SOCKET, SO_RCVBUF, &n, sizeof (n)))
+            tr_inf ("Unable to set SO_RCVBUF on socket %d: %s", s, tr_strerror (sockerrno));
     }
 
-    if( evutil_make_socket_nonblocking( s ) < 0 ) {
-        tr_netClose( session, s );
+    if (evutil_make_socket_nonblocking (s) < 0) {
+        tr_netClose (session, s);
         return -1;
     }
 
-    addrlen = setup_sockaddr( addr, port, &sock );
+    addrlen = setup_sockaddr (addr, port, &sock);
 
     /* set source address */
-    source_addr = tr_sessionGetPublicAddress( session, addr->type, NULL );
-    assert( source_addr );
-    sourcelen = setup_sockaddr( source_addr, 0, &source_sock );
-    if( bind( s, ( struct sockaddr * ) &source_sock, sourcelen ) )
+    source_addr = tr_sessionGetPublicAddress (session, addr->type, NULL);
+    assert (source_addr);
+    sourcelen = setup_sockaddr (source_addr, 0, &source_sock);
+    if (bind (s, (struct sockaddr *) &source_sock, sourcelen))
     {
-        tr_err( _( "Couldn't set source address %s on %d: %s" ),
-                tr_address_to_string( source_addr ), s, tr_strerror( errno ) );
+        tr_err (_("Couldn't set source address %s on %d: %s"),
+                tr_address_to_string (source_addr), s, tr_strerror (errno));
         return -errno;
     }
 
-    if( ( connect( s, (struct sockaddr *) &sock,
-                  addrlen ) < 0 )
+    if ((connect (s, (struct sockaddr *) &sock,
+                  addrlen) < 0)
 #ifdef WIN32
-      && ( sockerrno != WSAEWOULDBLOCK )
+      && (sockerrno != WSAEWOULDBLOCK)
 #endif
-      && ( sockerrno != EINPROGRESS ) )
+      && (sockerrno != EINPROGRESS))
     {
         int tmperrno;
         tmperrno = sockerrno;
-        if( ( tmperrno != ENETUNREACH && tmperrno != EHOSTUNREACH )
-                || addr->type == TR_AF_INET )
-            tr_err( _( "Couldn't connect socket %d to %s, port %d (errno %d - %s)" ),
-                    s, tr_address_to_string( addr ), (int)ntohs( port ), tmperrno,
-                    tr_strerror( tmperrno ) );
-        tr_netClose( session, s );
+        if ((tmperrno != ENETUNREACH && tmperrno != EHOSTUNREACH)
+                || addr->type == TR_AF_INET)
+            tr_err (_("Couldn't connect socket %d to %s, port %d (errno %d - %s)"),
+                    s, tr_address_to_string (addr), (int)ntohs (port), tmperrno,
+                    tr_strerror (tmperrno));
+        tr_netClose (session, s);
         s = -tmperrno;
     }
 
-    tr_deepLog( __FILE__, __LINE__, NULL, "New OUTGOING connection %d (%s)",
-               s, tr_peerIoAddrStr( addr, port ) );
+    tr_deepLog (__FILE__, __LINE__, NULL, "New OUTGOING connection %d (%s)",
+               s, tr_peerIoAddrStr (addr, port));
 
     return s;
 }
 
 struct UTPSocket *
-tr_netOpenPeerUTPSocket( tr_session        * session,
+tr_netOpenPeerUTPSocket (tr_session        * session,
                          const tr_address  * addr,
                          tr_port             port,
-                         bool                clientIsSeed UNUSED )
+                         bool                clientIsSeed UNUSED)
 {
-    struct sockaddr_storage ss;
-    socklen_t sslen;
-    sslen = setup_sockaddr( addr, port, &ss );
+  struct UTPSocket * ret = NULL;
 
-    return UTP_Create( tr_utpSendTo, (void*)session,
-                       (struct sockaddr*)&ss, sslen );
+  if (tr_address_is_valid_for_peers (addr, port))
+    {
+      struct sockaddr_storage ss;
+      const socklen_t sslen = setup_sockaddr (addr, port, &ss);
+      ret = UTP_Create (tr_utpSendTo, session, (struct sockaddr*)&ss, sslen);
+    }
+
+  return ret;
 }
 
 static int
-tr_netBindTCPImpl( const tr_address * addr, tr_port port, bool suppressMsgs, int * errOut )
+tr_netBindTCPImpl (const tr_address * addr, tr_port port, bool suppressMsgs, int * errOut)
 {
     static const int domains[NUM_TR_AF_INET_TYPES] = { AF_INET, AF_INET6 };
     struct sockaddr_storage sock;
@@ -315,64 +321,64 @@ tr_netBindTCPImpl( const tr_address * addr, tr_port port, bool suppressMsgs, int
     int addrlen;
     int optval;
 
-    assert( tr_address_is_valid( addr ) );
+    assert (tr_address_is_valid (addr));
 
-    fd = socket( domains[addr->type], SOCK_STREAM, 0 );
-    if( fd < 0 ) {
+    fd = socket (domains[addr->type], SOCK_STREAM, 0);
+    if (fd < 0) {
         *errOut = sockerrno;
         return -1;
     }
 
-    if( evutil_make_socket_nonblocking( fd ) < 0 ) {
+    if (evutil_make_socket_nonblocking (fd) < 0) {
         *errOut = sockerrno;
-        tr_netCloseSocket( fd );
+        tr_netCloseSocket (fd);
         return -1;
     }
 
     optval = 1;
-    setsockopt( fd, SOL_SOCKET, SO_KEEPALIVE, &optval, sizeof(optval) );
-    setsockopt( fd, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof(optval) );
+    setsockopt (fd, SOL_SOCKET, SO_KEEPALIVE, &optval, sizeof (optval));
+    setsockopt (fd, SOL_SOCKET, SO_REUSEADDR, &optval, sizeof (optval));
 
 #ifdef IPV6_V6ONLY
-    if( addr->type == TR_AF_INET6 )
-        if( setsockopt( fd, IPPROTO_IPV6, IPV6_V6ONLY, &optval, sizeof( optval ) ) == -1 )
-            if( sockerrno != ENOPROTOOPT ) { /* if the kernel doesn't support it, ignore it */
+    if (addr->type == TR_AF_INET6)
+        if (setsockopt (fd, IPPROTO_IPV6, IPV6_V6ONLY, &optval, sizeof (optval)) == -1)
+            if (sockerrno != ENOPROTOOPT) { /* if the kernel doesn't support it, ignore it */
                 *errOut = sockerrno;
                 return -1;
             }
 #endif
 
-    addrlen = setup_sockaddr( addr, htons( port ), &sock );
-    if( bind( fd, (struct sockaddr *) &sock, addrlen ) ) {
+    addrlen = setup_sockaddr (addr, htons (port), &sock);
+    if (bind (fd, (struct sockaddr *) &sock, addrlen)) {
         const int err = sockerrno;
-        if( !suppressMsgs )
+        if (!suppressMsgs)
         {
             const char * fmt;
             const char * hint;
 
-            if( err == EADDRINUSE )
-                hint = _( "Is another copy of Transmission already running?" );
+            if (err == EADDRINUSE)
+                hint = _("Is another copy of Transmission already running?");
             else
                 hint = NULL;
 
-            if( hint == NULL )
-                fmt = _( "Couldn't bind port %d on %s: %s" );
+            if (hint == NULL)
+                fmt = _("Couldn't bind port %d on %s: %s");
             else
-                fmt = _( "Couldn't bind port %d on %s: %s (%s)" );
+                fmt = _("Couldn't bind port %d on %s: %s (%s)");
 
-            tr_err( fmt, port, tr_address_to_string( addr ), tr_strerror( err ), hint );
+            tr_err (fmt, port, tr_address_to_string (addr), tr_strerror (err), hint);
         }
-        tr_netCloseSocket( fd );
+        tr_netCloseSocket (fd);
         *errOut = err;
         return -1;
     }
 
-    if( !suppressMsgs )
-        tr_dbg( "Bound socket %d to port %d on %s", fd, port, tr_address_to_string( addr ) );
+    if (!suppressMsgs)
+        tr_dbg ("Bound socket %d to port %d on %s", fd, port, tr_address_to_string (addr));
 
-    if( listen( fd, 128 ) == -1 ) {
+    if (listen (fd, 128) == -1) {
         *errOut = sockerrno;
-        tr_netCloseSocket( fd );
+        tr_netCloseSocket (fd);
         return -1;
     }
 
@@ -380,26 +386,26 @@ tr_netBindTCPImpl( const tr_address * addr, tr_port port, bool suppressMsgs, int
 }
 
 int
-tr_netBindTCP( const tr_address * addr, tr_port port, bool suppressMsgs )
+tr_netBindTCP (const tr_address * addr, tr_port port, bool suppressMsgs)
 {
     int unused;
-    return tr_netBindTCPImpl( addr, port, suppressMsgs, &unused );
+    return tr_netBindTCPImpl (addr, port, suppressMsgs, &unused);
 }
 
 bool
-tr_net_hasIPv6( tr_port port )
+tr_net_hasIPv6 (tr_port port)
 {
     static bool result = false;
     static bool alreadyDone = false;
 
-    if( !alreadyDone )
+    if (!alreadyDone)
     {
         int err;
-        int fd = tr_netBindTCPImpl( &tr_in6addr_any, port, true, &err );
-        if( fd >= 0 || err != EAFNOSUPPORT ) /* we support ipv6 */
+        int fd = tr_netBindTCPImpl (&tr_in6addr_any, port, true, &err);
+        if (fd >= 0 || err != EAFNOSUPPORT) /* we support ipv6 */
             result = true;
-        if( fd >= 0 )
-            tr_netCloseSocket( fd );
+        if (fd >= 0)
+            tr_netCloseSocket (fd);
         alreadyDone = true;
     }
 
@@ -407,15 +413,15 @@ tr_net_hasIPv6( tr_port port )
 }
 
 int
-tr_netAccept( tr_session  * session,
+tr_netAccept (tr_session  * session,
               int           b,
               tr_address  * addr,
-              tr_port     * port )
+              tr_port     * port)
 {
-    int fd = tr_fdSocketAccept( session, b, addr, port );
+    int fd = tr_fdSocketAccept (session, b, addr, port);
 
-    if( fd>=0 && evutil_make_socket_nonblocking(fd)<0 ) {
-        tr_netClose( session, fd );
+    if (fd>=0 && evutil_make_socket_nonblocking (fd)<0) {
+        tr_netClose (session, fd);
         fd = -1;
     }
 
@@ -423,19 +429,19 @@ tr_netAccept( tr_session  * session,
 }
 
 void
-tr_netCloseSocket( int fd )
+tr_netCloseSocket (int fd)
 {
-    evutil_closesocket( fd );
+    evutil_closesocket (fd);
 }
 
 void
-tr_netClose( tr_session * session, int s )
+tr_netClose (tr_session * session, int s)
 {
-    tr_fdSocketClose( session, s );
+    tr_fdSocketClose (session, s);
 }
 
 /*
-   get_source_address() and global_unicast_address() were written by
+   get_source_address () and global_unicast_address () were written by
    Juliusz Chroboczek, and are covered under the same license as dht.c.
    Please feel free to copy them into your software if it can help
    unbreaking the double-stack Internet. */
@@ -445,52 +451,52 @@ tr_netClose( tr_session * session, int s )
    a connected UDP socket (connected UDP... hmm...) and check its source
    address. */
 static int
-get_source_address( const struct sockaddr  * dst,
+get_source_address (const struct sockaddr  * dst,
                     socklen_t                dst_len,
                     struct sockaddr        * src,
-                    socklen_t              * src_len )
+                    socklen_t              * src_len)
 {
     int s, rc, save;
 
-    s = socket(dst->sa_family, SOCK_DGRAM, 0);
-    if(s < 0)
+    s = socket (dst->sa_family, SOCK_DGRAM, 0);
+    if (s < 0)
         goto fail;
 
     /* Since it's a UDP socket, this doesn't actually send any packets. */
-    rc = connect(s, dst, dst_len);
-    if(rc < 0)
+    rc = connect (s, dst, dst_len);
+    if (rc < 0)
         goto fail;
 
-    rc = getsockname(s, src, src_len);
-    if(rc < 0)
+    rc = getsockname (s, src, src_len);
+    if (rc < 0)
         goto fail;
 
-    evutil_closesocket( s );
+    evutil_closesocket (s);
 
     return rc;
 
  fail:
     save = errno;
-    evutil_closesocket( s );
+    evutil_closesocket (s);
     errno = save;
     return -1;
 }
 
 /* We all hate NATs. */
 static int
-global_unicast_address(struct sockaddr *sa)
+global_unicast_address (struct sockaddr *sa)
 {
-    if(sa->sa_family == AF_INET) {
+    if (sa->sa_family == AF_INET) {
         const unsigned char *a =
-            (unsigned char*)&((struct sockaddr_in*)sa)->sin_addr;
-        if(a[0] == 0 || a[0] == 127 || a[0] >= 224 ||
+          (unsigned char*)& ((struct sockaddr_in*)sa)->sin_addr;
+        if (a[0] == 0 || a[0] == 127 || a[0] >= 224 ||
            a[0] == 10 || (a[0] == 172 && a[1] >= 16 && a[1] <= 31) ||
-           (a[0] == 192 && a[1] == 168))
+         (a[0] == 192 && a[1] == 168))
             return 0;
         return 1;
-    } else if(sa->sa_family == AF_INET6) {
+    } else if (sa->sa_family == AF_INET6) {
         const unsigned char *a =
-            (unsigned char*)&((struct sockaddr_in6*)sa)->sin6_addr;
+          (unsigned char*)& ((struct sockaddr_in6*)sa)->sin6_addr;
         /* 2000::/3 */
         return (a[0] & 0xE0) == 0x20;
     } else {
@@ -500,58 +506,58 @@ global_unicast_address(struct sockaddr *sa)
 }
 
 static int
-tr_globalAddress( int af, void *addr, int *addr_len )
+tr_globalAddress (int af, void *addr, int *addr_len)
 {
     struct sockaddr_storage ss;
-    socklen_t sslen = sizeof(ss);
+    socklen_t sslen = sizeof (ss);
     struct sockaddr_in sin;
     struct sockaddr_in6 sin6;
     struct sockaddr *sa;
     socklen_t salen;
     int rc;
 
-    switch(af) {
+    switch (af) {
     case AF_INET:
-        memset(&sin, 0, sizeof(sin));
+        memset (&sin, 0, sizeof (sin));
         sin.sin_family = AF_INET;
-        evutil_inet_pton(AF_INET, "91.121.74.28", &sin.sin_addr);
-        sin.sin_port = htons(6969);
+        evutil_inet_pton (AF_INET, "91.121.74.28", &sin.sin_addr);
+        sin.sin_port = htons (6969);
         sa = (struct sockaddr*)&sin;
-        salen = sizeof(sin);
+        salen = sizeof (sin);
         break;
     case AF_INET6:
-        memset(&sin6, 0, sizeof(sin6));
+        memset (&sin6, 0, sizeof (sin6));
         sin6.sin6_family = AF_INET6;
         /* In order for address selection to work right, this should be
            a native IPv6 address, not Teredo or 6to4. */
-        evutil_inet_pton(AF_INET6, "2001:1890:1112:1::20", &sin6.sin6_addr);
-        sin6.sin6_port = htons(6969);
+        evutil_inet_pton (AF_INET6, "2001:1890:1112:1::20", &sin6.sin6_addr);
+        sin6.sin6_port = htons (6969);
         sa = (struct sockaddr*)&sin6;
-        salen = sizeof(sin6);
+        salen = sizeof (sin6);
         break;
     default:
         return -1;
     }
 
-    rc = get_source_address( sa, salen, (struct sockaddr*)&ss, &sslen );
+    rc = get_source_address (sa, salen, (struct sockaddr*)&ss, &sslen);
 
-    if( rc < 0 )
+    if (rc < 0)
         return -1;
 
-    if( !global_unicast_address( (struct sockaddr*)&ss) )
+    if (!global_unicast_address ((struct sockaddr*)&ss))
         return -1;
 
-    switch(af) {
+    switch (af) {
     case AF_INET:
-        if(*addr_len < 4)
+        if (*addr_len < 4)
             return -1;
-        memcpy(addr, &((struct sockaddr_in*)&ss)->sin_addr, 4);
+        memcpy (addr, & ((struct sockaddr_in*)&ss)->sin_addr, 4);
         *addr_len = 4;
         return 1;
     case AF_INET6:
-        if(*addr_len < 16)
+        if (*addr_len < 16)
             return -1;
-        memcpy(addr, &((struct sockaddr_in6*)&ss)->sin6_addr, 16);
+        memcpy (addr, & ((struct sockaddr_in6*)&ss)->sin6_addr, 16);
         *addr_len = 16;
         return 1;
     default:
@@ -562,19 +568,19 @@ tr_globalAddress( int af, void *addr, int *addr_len )
 /* Return our global IPv6 address, with caching. */
 
 const unsigned char *
-tr_globalIPv6( void )
+tr_globalIPv6 (void)
 {
     static unsigned char ipv6[16];
     static time_t last_time = 0;
     static int have_ipv6 = 0;
-    const time_t now = tr_time( );
+    const time_t now = tr_time ();
 
     /* Re-check every half hour */
-    if( last_time < now - 1800 )
+    if (last_time < now - 1800)
     {
         int addrlen = 16;
-        const int rc = tr_globalAddress( AF_INET6, ipv6, &addrlen );
-        have_ipv6 = ( rc >= 0 ) && ( addrlen == 16 );
+        const int rc = tr_globalAddress (AF_INET6, ipv6, &addrlen);
+        have_ipv6 = (rc >= 0) && (addrlen == 16);
         last_time = now;
     }
 
@@ -587,49 +593,49 @@ tr_globalIPv6( void )
 ***/
 
 static bool
-isIPv4MappedAddress( const tr_address * addr )
+isIPv4MappedAddress (const tr_address * addr)
 {
-    return ( addr->type == TR_AF_INET6 ) && IN6_IS_ADDR_V4MAPPED( &addr->addr.addr6 );
+    return (addr->type == TR_AF_INET6) && IN6_IS_ADDR_V4MAPPED (&addr->addr.addr6);
 }
 
 static bool
-isIPv6LinkLocalAddress( const tr_address * addr )
+isIPv6LinkLocalAddress (const tr_address * addr)
 {
-    return ( ( addr->type == TR_AF_INET6 )
-                  && IN6_IS_ADDR_LINKLOCAL( &addr->addr.addr6 ) );
+    return ((addr->type == TR_AF_INET6)
+                  && IN6_IS_ADDR_LINKLOCAL (&addr->addr.addr6));
 }
 
 /* isMartianAddr was written by Juliusz Chroboczek,
    and is covered under the same license as third-party/dht/dht.c. */
 static bool
-isMartianAddr( const struct tr_address * a )
+isMartianAddr (const struct tr_address * a)
 {
     static const unsigned char zeroes[16] =
         { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
-    assert( tr_address_is_valid( a ) );
+    assert (tr_address_is_valid (a));
 
-    switch( a->type )
+    switch (a->type)
     {
         case TR_AF_INET: {
             const unsigned char * address = (const unsigned char*)&a->addr.addr4;
             return (address[0] == 0) ||
-                   (address[0] == 127) ||
-                   ((address[0] & 0xE0) == 0xE0);
+                 (address[0] == 127) ||
+                 ((address[0] & 0xE0) == 0xE0);
             break;
         }
 
         case TR_AF_INET6: {
             const unsigned char * address = (const unsigned char*)&a->addr.addr6;
             return (address[0] == 0xFF) ||
-                   (memcmp(address, zeroes, 15) == 0 &&
-                    (address[15] == 0 || address[15] == 1)) ||
+                 (memcmp (address, zeroes, 15) == 0 &&
+                  (address[15] == 0 || address[15] == 1)) ||
                    /* Addresses outside of 2000::/3 are currently reserved,
                       but might be allocated at some future time. Since
                       there are a lot of buggy peers pushing around such
                       addresses over PEX, we reject them until the end of
                       the 13th Baktun. */
-                   (tr_time() < 1356130800 && (address[0] & 0xE0) != 0x20);
+                 (tr_time () < 1356130800 && (address[0] & 0xE0) != 0x20);
             break;
         }
 
@@ -639,11 +645,11 @@ isMartianAddr( const struct tr_address * a )
 }
 
 bool
-tr_address_is_valid_for_peers( const tr_address * addr, tr_port port )
+tr_address_is_valid_for_peers (const tr_address * addr, tr_port port)
 {
-    return ( port != 0 )
-        && ( tr_address_is_valid( addr ) )
-        && ( !isIPv6LinkLocalAddress( addr ) )
-        && ( !isIPv4MappedAddress( addr ) )
-        && ( !isMartianAddr( addr ) );
+    return (port != 0)
+        && (tr_address_is_valid (addr))
+        && (!isIPv6LinkLocalAddress (addr))
+        && (!isIPv4MappedAddress (addr))
+        && (!isMartianAddr (addr));
 }
